<?php
/* 
** ZABBIX
** Copyright (C) 2000-2005 SIA Zabbix
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**/
?>
<?php
	global $TRANSLATION;

	$TRANSLATION=array(

	"S_DATE_FORMAT_YMDHMS"=>			"d M H:i:s",
	"S_DATE_FORMAT_YMD"=>				"d M Y",
	"S_HTML_CHARSET"=>					"iso-8859-1",

//	acknow.php
	"S_ACKNOWLEDGES"=>					"Herkenningen",
	"S_ACKNOWLEDGE"=>					"Herkenning",
	"S_ACKNOWLEDGE_ALARM_BY"=>			"Bevesting Herkenning",
	"S_ADD_COMMENT_BY"=>				"Voeg opmerking toe",
	"S_COMMENT_ADDED"=>					"Opmering toegevoegd",
	"S_CANNOT_ADD_COMMENT"=>			"Kan opmerking niet toevoegen",
	"S_ALARM_ACKNOWLEDGES_BIG"=>		"ALARM HERKENNINGEN",

//	actionconf.php
	"S_CONFIGURATION_OF_ACTIONS"=>		"Configuratie van acties",
	"S_CONFIGURATION_OF_ACTIONS_BIG"=>	"CONFIGURATIE VAN ACTIES",
	"S_FILTER_HOST_GROUP"=>				"Filter: gastheer groep",
	"S_FILTER_HOST"=>					"Filter: gastheer",
	"S_FILTER_TRIGGER"=>				"Filter: Trekker",
	"S_FILTER_TRIGGER_NAME"=>			"Filter: Trekker naam",
	"S_FILTER_TRIGGER_SEVERITY"=>		"Filter: Trekker ernstheid",
	"S_FILTER_WHEN_TRIGGER_BECOMES"=>	"Filter: Wanneer een Trekker veranderd",
	"S_ACTION_TYPE"=>					"Actie type",
	"S_SEND_MESSAGE"=>					"Verzend bericht",
	"S_REMOTE_COMMAND"=>				"Remote commando",
	"S_FILTER"=>						"Filter",
	"S_FILTER_TYPE"=>					"Filter type",
	"S_TRIGGER_NAME"=>					"Trekker naam",
	"S_TRIGGER_SEVERITY"=>				"Trekker ernstheid",
	"S_TRIGGER_VALUE"=>					"Trekker waarde",
	"S_TIME_PERIOD"=>					"Tijd periode",
	"S_TRIGGER_DESCRIPTION"=>			"Trekker omschrijving",
	"S_CONDITIONS"=>					"Condities",
	"S_CONDITION"=>						"Condities",
	"S_NO_CONDITIONS_DEFINED"=>			"Geen condities gedefineerd",
	"S_ACTIONS_DELETED"=>				"Acties verwijderd",
	"S_CANNOT_DELETE_ACTIONS"=>			"Kan acties niet verwijderen",

//	actions.php
	"S_ACTIONS"=>						"Acties",
	"S_ACTIONS_BIG"=>					"ACTIES",
	"S_ACTION_ADDED"=>					"Actie toegevoegd",
	"S_CANNOT_ADD_ACTION"=>				"kan actie niet toevoegen",
	"S_ACTION_UPDATED"=>				"Actie bijgewerkt",
	"S_CANNOT_UPDATE_ACTION"=>			"Kan actie niet bijwerken",
	"S_ACTION_DELETED"=>				"Actie verwijderd",
	"S_CANNOT_DELETE_ACTION"=>			"Kan actie niet verwijderen",
	"S_SCOPE"=>							"Scoop",
	"S_SEND_MESSAGE_TO"=>				"Verzend bericht aan",
	"S_WHEN_TRIGGER"=>					"Wanneer Trekker",
	"S_DELAY"=>							"Vertraging",
	"S_SUBJECT"=>						"Onderwerp",
	"S_ON"=>							"AAN",
	"S_OFF"=>							"UIT",
	"S_NO_ACTIONS_DEFINED"=>			"Geen acties gedefineerd",
	"S_SINGLE_USER"=>					"Enkele gebruiker",
	"S_USER_GROUP"=>					"Gebruikers groep",
	"S_GROUP"=>							"Groep",
	"S_USER"=>							"Gebruiker",
	"S_ON_OR_OFF"=>						"AAN of UIT",
	"S_DELAY_BETWEEN_MESSAGES_IN_SEC"=>	"Vertraging tussen berichten (in sec)",
	"S_DELAY_BETWEEN_EXECUTIONS_IN_SEC"=>			"Vertraging tussen uitvoering (in sec)",
	"S_MESSAGE"=>						"Bericht",
	"S_THIS_TRIGGER_ONLY"=>				"Deze Trekker alleen",
	"S_ALL_TRIGGERS_OF_THIS_HOST"=>	"Alle Trekkers van deze of this gastheer",
	"S_ALL_TRIGGERS"=>					"All Trekkers",
	"S_USE_IF_TRIGGER_SEVERITY"=>		"Gebruik deze Trekker's ernstheid gelijk of meer is dan",
	"S_NOT_CLASSIFIED"=>				"Niet geclassificeerd",
	"S_INFORMATION"=>					"Informatie",
	"S_WARNING"=>						"Waarschuwing",
	"S_AVERAGE"=>						"Gemiddelde",
	"S_HIGH"=>							"Hoog",
	"S_DISASTER"=>						"Catastrofe",
	"S_CREATE_ACTION"=>					"Maak een actie",

//	alarms.php
	"S_ALARMS"=>						"Alarms",
	"S_ALARMS_SMALL"=>					"Alarms",
	"S_ALARMS_BIG"=>					"ALARMS",
	"S_SHOW_ONLY_LAST_100"=>			"Toon alleen de laatste 100",
	"S_SHOW_ALL"=>						"Toon alles",
	"S_TIME"=>							"Tijd",
	"S_STATUS"=>						"Status",
	"S_DURATION"=>						"Duur",
	"S_SUM"=>							"Som",
	"S_TRUE_BIG"=>						"WAAR",
	"S_FALSE_BIG"=>						"ONWAAR",
	"S_DISABLED_BIG"=>					"UITGESCHAKELD",
	"S_UNKNOWN_BIG"=>					"ONBEKEND",

//	actions.php
	"S_HISTORY_OF_ACTIONS_BIG"=>		"Geschiedenis van acties",
	"S_LATEST_ACTIONS"=>				"laatste acties",
	"S_ALERTS_BIG"=>					"Alarmen",
	"S_TYPE"=>							"Type",
	"S_RECIPIENTS"=>					"Ontvanger(s)",
	"S_ERROR"=>							"Fout",
	"S_SENT"=>							"Verzonden",
	"S_NOT_SENT"=>						"Niet verzonden",
	"S_NO_ACTIONS_FOUND"=>				"Geen acties gedefineerd",
	"S_SHOW_NEXT_100"=>					"Toon de volgende 100",
	"S_SHOW_PREVIOUS_100"=>				"Toon de vorige 100",

//	charts.php
	"S_CUSTOM_GRAPHS"=>					"Speciale grafieken",
	"S_GRAPHS_BIG"=>					"GRAFIEKEN",
	"S_NO_GRAPHS_TO_DISPLAY"=>			"Geen grafieken te tonen",
	"S_SELECT_GRAPH_TO_DISPLAY"=>		"Selecteer een grafiek om weer te geven",
	"S_PERIOD"=>						"Periode",
	"S_1H"=>							"1uur",
	"S_2H"=>							"2uur",
	"S_4H"=>							"4uur",
	"S_8H"=>							"8uur",
	"S_12H"=>							"12uur",
	"S_24H"=>							"24uur",
	"S_WEEK_SMALL"=>					"week",
	"S_MONTH_SMALL"=>					"maand",
	"S_YEAR_SMALL"=>					"jaar",
	"S_KEEP_PERIOD"=>					"Bewaar periode",
	"S_ON_C"=>							"Aan",
	"S_OFF_C"=>							"Uit",
	"S_MOVE"=>							"Verplaats",
	"S_NAVIGATE"=>						"Navigeer",
	"S_INCREASE"=>						"Verhoog",
	"S_DECREASE"=>						"Verlaag",
	"S_RIGHT_DIR"=>						"Rechts",
	"S_LEFT_DIR"=>						"Links",
	"S_SELECT_GRAPH_DOT_DOT_DOT"=>		"Selecteer een grafiek...",

// Colors
	"S_BLACK"=>							"Zwart",
	"S_BLUE"=>							"Blauw",
	"S_CYAN"=>							"Groenblauw",
	"S_DARK_BLUE"=>						"Donker blauw",
	"S_DARK_GREEN"=>					"Donker groen",
	"S_DARK_RED"=>						"Donker rood",
	"S_DARK_YELLOW"=>					"Donker geel",
	"S_GREEN"=>							"Groen",
	"S_RED"=>							"Rood",
	"S_WHITE"=>							"Wit",
	"S_YELLOW"=>						"Geel",

//	config.php
	"S_CANNNOT_UPDATE_VALUE_MAP"=>		"Kan map waarde niet bijwerken",
	"S_VALUE_MAP_ADDED"=>				"Waarde aan map toegevoegd",
	"S_CANNNOT_ADD_VALUE_MAP"=>			"Kan niet map waarde bijwerken",
	"S_VALUE_MAP_DELETED"=>				"Map waarde verwijderd",
	"S_CANNNOT_DELETE_VALUE_MAP"=>		"Kan niet map waarde verwijderen",
	"S_VALUE_MAP_UPDATED"=>				"Map waarde bijgewerkt",
	"S_VALUE_MAPPING_BIG"=>				"WAARDE AFBEELDING",
	"S_VALUE_MAPPING"=>					"Waarde afbeeldingen",
	"S_VALUE_MAP"=>						"Waarde afbeelding",
	"S_MAPPING"=>						"Afbeelding",
	"S_NEW_MAPPING"=>					"Nieuwe afbeelding",
	"S_NO_MAPPING_DEFINED"=>			"Geen afbeelding gedefineerd",
	"S_CREATE_VALUE_MAP"=>				"Maak waarde afbeelding",
	"S_CONFIGURATION_OF_ZABBIX"=>		"Configuratie van ZABBIX",
	"S_CONFIGURATION_OF_ZABBIX_BIG"=>	"CONFIGURATIE VAN ZABBIX",
	"S_CONFIGURATION_UPDATED"=>			"Configuratie bijgewerkt",
	"S_CONFIGURATION_WAS_NOT_UPDATED"=>	"Configuratie was niet bijgewerkt",
	"S_ADDED_NEW_MEDIA_TYPE"=>			"Nieuw media type toegevoegd",
	"S_NEW_MEDIA_TYPE_WAS_NOT_ADDED"=>	"Nieuw media type was niet toegevoegd",
	"S_MEDIA_TYPE_UPDATED"=>			"Media type bijgewerkt",
	"S_MEDIA_TYPE_WAS_NOT_UPDATED"=>	"Media type was niet bijgewerkt",
	"S_MEDIA_TYPE_DELETED"=>			"Media type verwijderd",
	"S_MEDIA_TYPE_WAS_NOT_DELETED"=>	"Media type was niet verwijderd",
	"S_CONFIGURATION"=>					"Configuratie",
	"S_DO_NOT_KEEP_ACTIONS_OLDER_THAN"=>	"Bewaar geen acties ouder dan (in dagen)",
	"S_DO_NOT_KEEP_EVENTS_OLDER_THAN"=>		"Bewaar geen gebeurtenissen ouder dan (in dagen)",
	"S_MEDIA_TYPES_BIG"=>				"MEDIA TYPES",
	"S_NO_MEDIA_TYPES_DEFINED"=>		"Geen media types gedefineerd",
	"S_SMTP_SERVER"=>					"SMTP Server",
	"S_SMTP_HELO"=>						"SMTP Groet",
	"S_SMTP_EMAIL"=>					"SMTP Email",
	"S_SCRIPT_NAME"=>					"Script naam",
	"S_DELETE_SELECTED_MEDIA"=>			"Verwijder geselecteerde media?",
	"S_DELETE_SELECTED_IMAGE"=>			"Verwijder geselecteerde afbeelding?",
	"S_HOUSEKEEPER"=>					"Huishoudster",
	"S_MEDIA_TYPES"=>					"Media types",
	"S_ESCALATION_RULES"=>				"Escalatie regels",
	"S_ESCALATION"=>					"Escalatie",
	"S_ESCALATION_RULES_BIG"=>			"ESCALATIE REGELS",
	"S_NO_ESCALATION_RULES_DEFINED"=>	"Geen escalatie regels gedefineerd",
	"S_NO_ESCALATION_DETAILS"=>			"Geen escalatie details",
	"S_ESCALATION_DETAILS_BIG"=>		"ESCALATIE DETAILS",
	"S_ESCALATION_ADDED"=>				"Escalatie toegevoegd",
	"S_ESCALATION_WAS_NOT_ADDED"=>		"Escalatie was niet toegevoegd",
	"S_ESCALATION_RULE_ADDED"=>			"Escalatie regels toegevoegd",
	"S_ESCALATION_RULE_WAS_NOT_ADDED"=>	"Escalatie regels was niet toegevoegd",
	"S_ESCALATION_RULE_UPDATED"=>		"Escalatie regels bijgewerkt",
	"S_ESCALATION_RULE_WAS_NOT_UPDATED"=>	"Escalatioe regel was niet bijgewerkt",
	"S_ESCALATION_RULE_DELETED"=>			"Escalation regel verwijderd",
	"S_ESCALATION_RULE_WAS_NOT_DELETED"=>	"Escalation regel was niet verwijderd",
	"S_ESCALATION_UPDATED"=>			"Escalatie bijgewerkt",
	"S_ESCALATION_WAS_NOT_UPDATED"=>	"Escalatie was niet bijgewerkt",
	"S_ESCALATION_DELETED"=>			"Escalatie verwijderd",
	"S_ESCALATION_WAS_NOT_DELETED"=>	"Escalatie was niet verwijderd",
	"S_ESCALATION_RULE"=>				"Escalatie regel",
	"S_DO"=>							"Doen",
	"S_DEFAULT"=>						"Standaard",
	"S_IS_DEFAULT"=>					"Is standaard",
	"S_LEVEL"=>							"Nivo",
	"S_DELAY_BEFORE_ACTION"=>			"Vertraging voor actie",
	"S_IMAGES"=>						"Afbeeldingen",
	"S_IMAGE"=>							"Afbeelding",
	"S_IMAGES_BIG"=>					"AFBEELDINGEN",
	"S_ICON"=>							"Icoon",
	"S_NO_IMAGES_DEFINED"=>				"Geen afbeelding gedefineerd",
	"S_BACKGROUND"=>					"Achtergrond",
	"S_UPLOAD"=>						"Upload",
	"S_IMAGE_ADDED"=>					"Afbeelding toegevoegd",
	"S_CANNOT_ADD_IMAGE"=>				"Kan afbeelding niet toevoegen",
	"S_IMAGE_DELETED"=>					"Afbeelding verwijderd",
	"S_CANNOT_DELETE_IMAGE"=>			"Kan niet afbeelding verwijderen",
	"S_IMAGE_UPDATED"=>					"Afbeelding bijgewerkt",
	"S_CANNOT_UPDATE_IMAGE"=>			"Kan niet afbeelding bijwerken",
	"S_UPDATE_SELECTED_IMAGE"=>			"Werk bij geselecteerde afbeelding?",
	"S_PRIORITY"=>						"Prioriteit",
	"S_PATTERN"=>						"Patroon",
	"S_OTHER"=>								"Anders",
	"S_OTHER_PARAMETERS"=>					"Andere parameters",
	"S_REFRESH_UNSUPPORTED_ITEMS"=>		"Vernieuw niet ondersteunde items (in sec)",
	"S_CREATE_MEDIA_TYPE"=>				"Crer Media Type",
	"S_CREATE_IMAGE"=>					"Crer Afbeelding",
	"S_CREATE_RULE"=>					"Crer Regel",
	"S_WORKING_TIME"=>					"Werk tijd",

//	Latest values
	"S_LATEST_VALUES"=>					"Laatste waardes",
	"S_NO_PERMISSIONS"=>				"Geen toegang !",
	"S_LATEST_DATA_BIG"=>				"LAATSTE DATA",
	"S_ALL_SMALL"=>						"alle",
	"S_MINUS_ALL_MINUS"=>				"- alle -",
	"S_MINUS_OTHER_MINUS"=>				"- andere -",
	"S_DESCRIPTION_LARGE"=>				"OMSCHRIJVING",
	"S_DESCRIPTION_SMALL"=>				"Omschrijving",
	"S_GRAPH"=>							"Grafiek",
	"S_TREND"=>							"Trend",
	"S_COMPARE"=>						"Vergelijk",

//	Footer
	"S_CONNECTED_AS"=>					"Verbonden als",

//	graph.php
	"S_CONFIGURATION_OF_GRAPH"=>		"Configuratie van grafieken",
	"S_CONFIGURATION_OF_GRAPH_BIG"=>	"CONFIGURATIE VAN GRAFIEKEN",
	"S_ITEM_ADDED"=>					"Item toegevoegd",
	"S_ITEM_UPDATED"=>					"Item bijgewerkt",
	"S_SORT_ORDER_UPDATED"=>			"Sorteer orde bijgewerkt",
	"S_CANNOT_UPDATE_SORT_ORDER"=>		"Kan sorteer orde niet bijgewerkt",
	"S_DISPLAYED_PARAMETERS_BIG"=>		"WEERGEGEVEN PARAMETERS",
	"S_SORT_ORDER"=>					"Sorteer orde",
	"S_PARAMETER"=>						"Parameter",
	"S_COLOR"=>							"Kleur",
	"S_UP"=>							"Omhoog",
	"S_DOWN"=>							"Omlaag",
	"S_NEW_ITEM_FOR_THE_GRAPH"=>		"Nieuw item voor de grafiek",
	"S_SORT_ORDER_1_100"=>				"Sorteer orde (0->100)",
	"S_YAXIS_SIDE"=>					"Y lijn zijde",
	"S_LEFT"=>							"Links",
	"S_FUNCTION"=>						"Functie",
	"S_MIN_SMALL"=>						"min",
	"S_AVG_SMALL"=>						"gmd",
	"S_MAX_SMALL"=>						"max",
	"S_DRAW_STYLE"=>					"Afbeelding stijl",
	"S_SIMPLE"=>						"Simpel",
	"S_AGGREGATED"=>					"Aggregatie",
	"S_AGGREGATED_PERIODS_COUNT"=>		"Aggregatie periode telling",

//	graphs.php
	"S_CONFIGURATION_OF_GRAPHS"=>		"Configuratie van grafieken",
	"S_CONFIGURATION_OF_GRAPHS_BIG"=>	"CONFIGURATIE VAN GRAFIEKEN",
	"S_GRAPH_ADDED"=>					"Grafiek toegevoegd",
	"S_GRAPH_UPDATED"=>					"Grafiek bijgewerkt",
	"S_CANNOT_UPDATE_GRAPH"=>			"Kan grafiek niet bijwerken",
	"S_GRAPH_DELETED"=>					"Grafiek verwijderd",
	"S_CANNOT_DELETE_GRAPH"=>			"Kan grafiek niet verwijderen",
	"S_CANNOT_ADD_GRAPH"=>				"Kan grefiek niet toevoegen",
	"S_ID"=>							"Id",
	"S_NO_GRAPHS_DEFINED"=>				"Geen grafieken gedefineerd",
	"S_DELETE_GRAPH_Q"=>				"Verwijder grafiek?",
	"S_YAXIS_TYPE"=>					"Y lijn type",
	"S_YAXIS_MIN_VALUE"=>				"Y lijn MIN waarde",
	"S_YAXIS_MAX_VALUE"=>				"Y lijn MAX waarde",
	"S_CALCULATED"=>					"Gecalculeerd",
	"S_FIXED"=>							"Statisch",
	"S_CREATE_GRAPH"=>					"Crer Grafiek",
	"S_SHOW_WORKING_TIME"=>				"Toon werk tijden",
	"S_SHOW_TRIGGERS"=>					"Toon Trekkers",

//	history.php
	"S_LAST_HOUR_GRAPH"=>				"Laatste uur grafiek",
	"S_VALUES_OF_LAST_HOUR"=>			"waardes van het laatste uur",
	"S_500_LATEST_VALUES"=>				"500 laatste waardes",
	"S_GRAPH_OF_SPECIFIED_PERIOD"=>		"Grafiek van een gespecificeerde periode",
	"S_VALUES_OF_SPECIFIED_PERIOD"=>	"Waardes van een gespecificeerde periode",
	"S_VALUES_IN_PLAIN_TEXT_FORMAT"=>	"Waardes in normaal tekst formaat",
	"S_TIMESTAMP"=>						"Tijdsstempel",
	"S_LOCAL"=>							"Lokaal",
	"S_SOURCE"=>						"Bron",

	"S_SHOW_SELECTED"=>					"Toon geselecteerde",
	"S_HIDE_SELECTED"=>					"Verberg geselecteerde",
	"S_MARK_SELECTED"=>					"Markeer geselecteerde",
	"S_MARK_OTHERS"=>					"Markeer andere",

	"S_AS_RED"=>						"als Rood",
	"S_AS_GREEN"=>						"als Groen",
	"S_AS_BLUE"=>						"als Blauw",

//	gastheers.php
	"S_APPLICATION"=>					"Applicatie",
	"S_APPLICATIONS"=>					"Applicaties",
	"S_APPLICATIONS_BIG"=>				"APPLICATIES",
	"S_CREATE_APPLICATION"=>			"Crer applicatie",	
	"S_DELETE_SELECTED_APPLICATIONS_Q"=>				"Verwijder geselecteerde applicaties?",
	"S_DISABLE_ITEMS_FROM_SELECTED_APPLICATIONS_Q"=>	"Deactiveer items van geselecteerde applicaties?",
	"S_ACTIVATE_ITEMS_FROM_SELECTED_APPLICATIONS_Q"=>	"Activeer items van geselecteerde applicaties?",
	"S_APPLICATION_UPDATED"=>			"Applicatie bijgewerkt",
	"S_CANNOT_UPDATE_APPLICATION"=>		"Kan applicatie niet bijwerken",
	"S_APPLICATION_ADDED"=>				"Applicatie toegevoegd",
	"S_CANNOT_ADD_APPLICATION"=>		"Kan applicatie niet toevoegen",
	"S_APPLICATION_DELETED"=>			"Applicatie verwijderd",
	"S_CANNOT_DELETE_APPLICATION"=>		"Kan applicatie niet verwijderen",

	"S_HOSTS"=>							"Gastheren",
	"S_ITEMS"=>							"Items",
	"S_ITEMS_BIG"=>						"ITEMS",
	"S_TRIGGERS"=>						"Trekkers",
	"S_GRAPHS"=>						"Grafieken",
	"S_HOST_ADDED"=>					"Gastheer toegevoegd",
	"S_CANNOT_ADD_HOST"=>				"kan gastheer niet toevoegen",
	"S_ITEMS_ADDED"=>					"Items toegeveoegd",
	"S_CANNOT_ADD_ITEMS"=>				"kan niet items toevoegen",
	"S_HOST_UPDATED"=>					"Gastheer bijgewerkt",
	"S_CANNOT_UPDATE_HOST"=>			"kan gastheer niet bijwerken",
	"S_HOST_STATUS_UPDATED"=>			"Gastheer status bijgewerkt",
	"S_CANNOT_UPDATE_HOST_STATUS"=>		"Kan gastheer status niet bijwerken",
	"S_HOST_DELETED"=>					"Gastheer verwijderd",
	"S_CANNOT_DELETE_HOST"=>			"Kan gastheer niet verwijderen",
	"S_TEMPLATE_LINKAGE_ADDED"=>		"Sjabloon verbinding toegevoegd",
	"S_CANNOT_ADD_TEMPLATE_LINKAGE"=>	"Kan sjabloon verbinding niet toevoegen",
	"S_TEMPLATE_LINKAGE_UPDATED"=>		"Sjabloon verbinding bijgewerkt",
	"S_CANNOT_UPDATE_TEMPLATE_LINKAGE"=>"Kan sjabloon verbinding niet bijwerken",
	"S_TEMPLATE_LINKAGE_DELETED"=>		"Sjabloon verbinding verwijderd",
	"S_CANNOT_DELETE_TEMPLATE_LINKAGE"=>"Kan sjabloon verbinding niet verwijderen",
	"S_CONFIGURATION_OF_HOSTS_GROUPS_AND_TEMPLATES"=>"CONFIGURATIE VAN GASTHEREN, GROEPEN EN SJABLONEN",
	"S_HOST_GROUPS_BIG"=>				"GASTHEER GROEPEN",
	"S_START"=>							"Start",
	"S_STOP"=>							"Stop",
	"S_NO_HOST_GROUPS_DEFINED"=>		"Geen gastheer groepen gedefineerd",
	"S_NO_LINKAGES_DEFINED"=>			"Geen verbindingen gedefineerd",
	"S_NO_HOSTS_DEFINED"=>				"Geen gastheren gedefineerd",
	"S_HOSTS_BIG"=>						"GASTHEREN",
	"S_HOST"=>							"Gastheer",
	"S_IP"=>							"IP",
	"S_PORT"=>							"Poort",
	"S_MONITORED"=>						"Gemonitord",
	"S_NOT_MONITORED"=>					"Niet gemonitord",
	"S_UNREACHABLE"=>					"Onbereikbaar",
	"S_TEMPLATE"=>						"Sjabloon",
	"S_DELETED"=>						"Verwijderd",
	"S_UNKNOWN"=>						"Onbekend",
	"S_GROUPS"=>						"Groepen",
	"S_NEW_GROUP"=>						"Nieuwe groep",
	"S_USE_IP_ADDRESS"=>				"Gebruik IP adres",
	"S_IP_ADDRESS"=>					"IP adres",
//	"S_USE_THE_gastheer_AS_A_TEMPLATE"=>		"Use the gastheer as a template",
//	"S_USE_TEMPLATES_OF_THIS_HOST"=>		"Use templates of this gastheer",
	"S_LINK_WITH_TEMPLATE"=>			"Verbind met Sjabloon",
	"S_USE_PROFILE"=>					"Gebruik Profiel",
	"S_DELETE_SELECTED_HOST_Q"=>		"Verwijder geselecteerde gastheer?",
	"S_DELETE_SELECTED_GROUP_Q"=>		"Verwijder geselecteerde groep?",
	"S_DELETE_SELECTED_GROUPS_Q"=>		"Verwijder geselecteerde groepen?",
	"S_GROUP_NAME"=>					"Groep naam",
	"S_HOST_GROUP"=>					"Gastheer groep",
	"S_HOST_GROUPS"=>					"Gastheer groepen",
	"S_UPDATE"=>						"Bijwerken",
	"S_AVAILABILITY"=>					"Beschikbaarheid",
	"S_AVAILABLE"=>						"Beschikbaar",
	"S_NOT_AVAILABLE"=>					"Niet beschikbaar",
//	gastheer profiles
	"S_HOST_PROFILE"=>					"Gastheer profiel",
	"S_DEVICE_TYPE"=>					"Apparaat type",
	"S_OS"=>							"Besturingssysteem",
	"S_SERIALNO"=>						"Serienummer",
	"S_TAG"=>							"Etiket",
	"S_HARDWARE"=>						"Hardware",
	"S_SOFTWARE"=>						"Software",
	"S_CONTACT"=>						"Contact",
	"S_LOCATION"=>						"Locatie",
	"S_NOTES"=>							"Opmerkingen",
	"S_MACADDRESS"=>					"MAC Adres",
	"S_PROFILE_ADDED"=>					"Profiel toegevoegd",
	"S_CANNOT_ADD_PROFILE"=>			"Kan profiel niet toevoegen",
	"S_PROFILE_UPDATED"=>				"Profiel bijgewerkt",
	"S_CANNOT_UPDATE_PROFILE"=>			"Kan profiel niet bijwerken",
	"S_PROFILE_DELETED"=>				"Profiel verwijderd",
	"S_CANNOT_DELETE_PROFILE"=>			"Kan profiel niet verwijderen",
	"S_ADD_TO_GROUP"=>					"Toevoegen aan groep",
	"S_DELETE_FROM_GROUP"=>				"Verwijder in groep",
	"S_UPDATE_IN_GROUP"=>				"Bijwerken in groep",
	"S_DELETE_SELECTED_HOSTS_Q"=>		"Verwijder geselecteerde gastheren?",
	"S_DISABLE_SELECTED_HOSTS_Q"=>		"Deactiveer geselecteerde gastheren?",
	"S_ACTIVATE_SELECTED_HOSTS_Q"=>		"Activeer geselecteerde gastheren?",
	"S_SELECT_HOST_TEMPLATE_FIRST"=>	"Selecteer gastheer sjabloon eerst",
	"S_CREATE_HOST"=>					"Crer Gastheer",
	"S_CREATE_TEMPLATE"=>				"Crer Sjabloon",
	"S_TEMPLATE_LINKAGE"=>				"Sjabloon verbindingen",
	"S_TEMPLATE_LINKAGE_BIG"=>			"SJABLOON VERBINDINGEN",
	"S_NO_LINKAGES"=>					"Geen Verbindingen",
	"S_TEMPLATES"=>						"Sjablonen",
	"S_TEMPLATES_BIG"=>					"SJABLONEN",
	"S_HOSTS"=>							"Gastheren",

//	items.php
	"S_NO_ITEMS_DEFINED"=>				"Geen items gedefineerd",
	"S_HISTORY_CLEANED"=>				"Geschiedenis opgeschoond",
	"S_CANNOT_CLEAN_HISTORY"=>			"Kan geschiedenis niet opschonen",
	"S_CONFIGURATION_OF_ITEMS"=>		"Configuratie van items",
	"S_CONFIGURATION_OF_ITEMS_BIG"=>	"CONFIGURATIE VAN ITEMS",
	"S_CANNOT_UPDATE_ITEM"=>			"Kan item niet bijwerken",
	"S_STATUS_UPDATED"=>				"Status bijgewerkt",
	"S_CANNOT_UPDATE_STATUS"=>			"kan status niet bijwerken",
	"S_CANNOT_ADD_ITEM"=>				"Kan item niet toevoegen",
	"S_ITEM_DELETED"=>					"Item verwijderd",
	"S_CANNOT_DELETE_ITEM"=>			"Kan item niet verwijderen",
	"S_ITEMS_DELETED"=>					"Items verwijderd",
	"S_CANNOT_DELETE_ITEMS"=>			"Kan items niet verwijderen",
	"S_ITEMS_ACTIVATED"=>				"Items geactiveerd",
	"S_CANNOT_ACTIVATE_ITEMS"=>			"Kan items niet activeren",
	"S_ITEMS_DISABLED"=>				"Items gedeactiveerd",
	"S_CANNOT_DISABLE_ITEMS"=>			"Kan items niet deactiveren",
	"S_SERVERNAME"=>					"Server Naam",
	"S_KEY"=>							"Sleutel",
	"S_DESCRIPTION"=>					"Omschrijving",
	"S_UPDATE_INTERVAL"=>				"Bijwerk interval",
	"S_HISTORY"=>						"Geschiedenis",
	"S_TRENDS"=>						"Trends",
	"S_SHORT_NAME"=>					"Korte naam",
	"S_ZABBIX_AGENT"=>					"ZABBIX agent",
	"S_ZABBIX_AGENT_ACTIVE"=>			"ZABBIX agent (actief)",
	"S_SNMPV1_AGENT"=>					"SNMPv1 agent",
	"S_ZABBIX_TRAPPER"=>				"ZABBIX trapper",
	"S_SIMPLE_CHECK"=>					"Simple check",
	"S_SNMPV2_AGENT"=>					"SNMPv2 agent",
	"S_SNMPV3_AGENT"=>					"SNMPv3 agent",
	"S_ZABBIX_INTERNAL"=>				"ZABBIX intern",
	"S_ZABBIX_AGGREGATE"=>				"ZABBIX gezamenlijk",
	"S_ZABBIX_UNKNOWN"=>				"Onbekend",
	"S_ACTIVE"=>						"Actief",
	"S_NOT_ACTIVE"=>					"Niet actief",
	"S_NOT_SUPPORTED"=>					"Niet ondersteund",
	"S_ACTIVATE_SELECTED_ITEMS_Q"=>		"Activeer geselecteerde items?",
	"S_DISABLE_SELECTED_ITEMS_Q"=>		"Deactiveer geselecteerde items?",
	"S_DELETE_SELECTED_ITEMS_Q"=>		"Verwijder geselecteerde items?",
	"S_EMAIL"=>							"Email",
	"S_SCRIPT"=>						"Script",
	"S_SMS"=>							"SMS",
	"S_GSM_MODEM"=>						"GSM modem",
	"S_UNITS"=>							"Eenheden",
	"S_MULTIPLIER"=>					"Vermenigvuldiger",
	"S_UPDATE_INTERVAL_IN_SEC"=>		"Bijwerk interval (in sec)",
	"S_KEEP_HISTORY_IN_DAYS"=>			"Bewaar geschiedenis (in dagen)",
	"S_KEEP_TRENDS_IN_DAYS"=>			"Bewaar trends (in dagen)",
	"S_TYPE_OF_INFORMATION"=>			"Type informatie",
	"S_STORE_VALUE"=>					"Bewaar waarde",
	"S_SHOW_VALUE"=>					"Toon waarde",
	"S_NUMERIC_UINT64"=>				"Numeriek (integer 64bit)",
	"S_NUMERIC_FLOAT"=>					"Numeriek (zwevend)",
	"S_CHARACTER"=>						"Karakter",
	"S_LOG"=>							"Log",
	"S_TEXT"=>							"Tekst",
	"S_AS_IS"=>							"Als is",
	"S_DELTA_SPEED_PER_SECOND"=>		"Delta (snelheid per seconden)",
	"S_DELTA_SIMPLE_CHANGE"=>			"Delta (simpele verandering)",
	"S_ITEM"=>							"Item",
	"S_SNMP_COMMUNITY"=>				"SNMP gemeenschap",
	"S_SNMP_OID"=>						"SNMP OID",
	"S_SNMP_PORT"=>						"SNMP poort",
	"S_ALLOWED_HOSTS"=>				"Toegestane gastheren",
	"S_SNMPV3_SECURITY_NAME"=>			"SNMPv3 Beveiligings naam",
	"S_SNMPV3_SECURITY_LEVEL"=>			"SNMPv3 Beveiligings nivo",
	"S_SNMPV3_AUTH_PASSPHRASE"=>		"SNMPv3 auth inhaalfase",
	"S_SNMPV3_PRIV_PASSPHRASE"=>		"SNMPv3 rechten inhaalfase",
	"S_CUSTOM_MULTIPLIER"=>				"Aangepaste vermenigvuldiging",
	"S_DO_NOT_USE"=>					"Niet in gebruik",
	"S_USE_MULTIPLIER"=>				"Gebruik vermenigvuldiger",
	"S_SELECT_HOST_DOT_DOT_DOT"=>		"Selecteer gastheer...",
	"S_LOG_TIME_FORMAT"=>				"Log tijd formaat",
	"S_CREATE_ITEM"=>					"Crer Item",
	"S_ADD_ITEM"=>						"Crer Item",

//	events.php
	"S_LATEST_EVENTS"=>					"Laatste gebeurtenissen",
	"S_HISTORY_OF_EVENTS_BIG"=>			"GESCHIEDENIS VAN GEBEURTENISSEN",
	"S_NO_EVENTS_FOUND"=>				"Geen gebeurtenissen gevonden",

//	latest.php
	"S_LAST_CHECK"=>					"Laatste controle",
	"S_LAST_CHECK_BIG"=>				"LAATSTE CONTROLE",
	"S_LAST_VALUE"=>					"Laatste waardes",

//	sysmap.php
	"S_LINK"=>							"Link",
	"S_LABEL"=>							"Label",
	"S_X"=>								"X",
	"S_Y"=>								"Y",
	"S_ICON_ON"=>						"Icoon (aan)",
	"S_ICON_OFF"=>						"Icoon (uit)",
	"S_ELEMENT_1"=>						"Element 1",
	"S_ELEMENT_2"=>						"Element 2",
	"S_LINK_STATUS_INDICATOR"=>			"Link status indicator",
	"S_CONFIGURATION_OF_NETWORK_MAPS"=>	"Configuratie van netwerk mappen",

//	sysmaps.php
	"S_MAPS_BIG"=>						"MAPPEN",
	"S_NO_MAPS_DEFINED"=>				"Geen mappen No maps gedefineerd",
	"S_CONFIGURATION_OF_NETWORK_MAPS"=>	"CONFIGURATIE VAN NETWERK MAPPEN",
	"S_CREATE_MAP"=>					"Crer Map",
	"S_ICON_LABEL_LOCATION"=>			"Icoon label locatie",
	"S_BOTTOM"=>						"Onder",
	"S_TOP"=>							"Boven",

//	map.php
	"S_OK_BIG"=>						"OK",
	"S_PROBLEMS_SMALL"=>				"problemen",
	"S_ZABBIX_URL"=>					"http://www.zabbix.com",

//	maps.php
	"S_NETWORK_MAPS"=>					"Netwerk mappen",
	"S_NETWORK_MAPS_BIG"=>				"NETWERK MAPPEN",
	"S_NO_MAPS_TO_DISPLAY"=>			"Geen mappen weer te geven",
	"S_SELECT_MAP_TO_DISPLAY"=>			"Selecteer een map om weer te geven",
	"S_SELECT_MAP_DOT_DOT_DOT"=>		"Selecteer map...",
	"S_BACKGROUND_IMAGE"=>				"Achtergrond afbeelding",
	"S_ICON_LABEL_TYPE"=>				"Icoon label type",
	"S_LABEL"=>							"Label",
	"S_LABEL_LOCATION"=>				"Label locatie",
	"S_ELEMENT_NAME"=>					"Element naam",
	"S_STATUS_ONLY"=>					"Status alleen",
	"S_NOTHING"=>						"Niets",

//	media.php
	"S_MEDIA"=>							"Media",
	"S_MEDIA_BIG"=>						"MEDIA",
	"S_MEDIA_ACTIVATED"=>				"Media geactiveerd",
	"S_CANNOT_ACTIVATE_MEDIA"=>			"Kan media niet activeren",
	"S_MEDIA_DISABLED"=>				"Media gedeactiveerd",
	"S_CANNOT_DISABLE_MEDIA"=>			"Kan media niet deactiveren",
	"S_MEDIA_ADDED"=>					"Media toegevoegd",
	"S_CANNOT_ADD_MEDIA"=>				"Kan media niet toevoegen",
	"S_MEDIA_UPDATED"=>					"Media bijgewerkt",
	"S_CANNOT_UPDATE_MEDIA"=>			"Kan media niet bijwerken",
	"S_MEDIA_DELETED"=>					"Media verwijder",
	"S_CANNOT_DELETE_MEDIA"=>			"Kan media niet verwijderen",
	"S_SEND_TO"=>						"Verzend aan",
	"S_WHEN_ACTIVE"=>					"Wanneer actief",
	"S_NO_MEDIA_DEFINED"=>				"Geen media gedefineerd",
	"S_NEW_MEDIA"=>						"Nieuw media",
	"S_USE_IF_SEVERITY"=>				"Gebruiks als ernstheid",
	"S_DELETE_SELECTED_MEDIA_Q"=>		"Verwijder geselecteerde media?",
	"S_CREATE_MEDIA"=>					"Crer Media",
	"S_SAVE"=>							"Bewaar",
	"S_CANCEL"=>						"Annuleer",

//	Menu
	"S_MENU_LATEST_VALUES"=>			"LAATSTE WAARDES",
	"S_MENU_TRIGGERS"=>					"Trekkers",
	"S_MENU_QUEUE"=>					"WACHTRIJ",
	"S_MENU_ALARMS"=>					"ALARMEN",
	"S_MENU_ALERTS"=>					"ALARMEREN",
	"S_MENU_NETWORK_MAPS"=>				"NETWERK MAPPEN",
	"S_MENU_GRAPHS"=>					"GRAFIEKEN",
	"S_MENU_SCREENS"=>					"SCHERMEN",
	"S_MENU_IT_SERVICES"=>				"IT DIENSTEN",
	"S_MENU_HOME"=>						"THUIS",
	"S_MENU_ABOUT"=>					"IN OMLOOP",
	"S_MENU_STATUS_OF_ZABBIX"=>			"STATUS VAN ZABBIX",
	"S_MENU_AVAILABILITY_REPORT"=>		"BESCHIKBAARHEIDS REPORT",
	"S_MENU_CONFIG"=>					"CONFIG",
	"S_MENU_USERS"=>					"GEBRUIKERS",
	"S_MENU_HOSTS"=>					"GASTHEREN",
	"S_MENU_ITEMS"=>					"ITEMS",
	"S_MENU_AUDIT"=>					"NAZIEN",

//	overview.php
	"S_SELECT_GROUP_DOT_DOT_DOT"=>		"Selecteer groep ...",
	"S_OVERVIEW"=>						"Overzicht",
	"S_OVERVIEW_BIG"=>					"OVERZICHT",
	"S_EXCL"=>							"!",
	"S_DATA"=>							"Data",

//	queue.php
	"S_QUEUE_BIG"=>						"WACHTRIJ",
	"S_QUEUE_OF_ITEMS_TO_BE_UPDATED_BIG"=>	"WACHTRIJ VAN ITEMS OM BIJGEWERKT TE WORDEN",
	"S_NEXT_CHECK"=>					"Volgende controle",
	"S_THE_QUEUE_IS_EMPTY"=>			"De wachtrij is leeg",
	"S_TOTAL"=>							"Totaal",
	"S_COUNT"=>							"Telling",
	"S_5_SECONDS"=>						"5 seconden",
	"S_10_SECONDS"=>					"10 seconden",
	"S_30_SECONDS"=>					"30 seconden",
	"S_1_MINUTE"=>						"1 minuut",
	"S_5_MINUTES"=>						"5 minuten",
	"S_MORE_THAN_5_MINUTES"=>			"Meer dan 5 minuten",

//	report1.php
	"S_STATUS_OF_ZABBIX"=>				"Status van ZABBIX",
	"S_STATUS_OF_ZABBIX_BIG"=>			"STATUS van ZABBIX",
	"S_VALUE"=>							"Waarde",
	"S_ZABBIX_SERVER_IS_RUNNING"=>		"Zabbix Server Actief",
	"S_NUMBER_OF_VALUES_STORED"=>		"Aantal Opgeslagen Waardes",
	"S_VALUES_STORED"=>					"Waardes Opgeslagen",
	"S_NUMBER_OF_TRENDS_STORED"=>		"Aantal Opgeslagen Trends",
	"S_TRENDS_STORED"=>					"Trends Opgeslagen",
	"S_NUMBER_OF_ALARMS"=>				"Aantal Alarmen",
	"S_NUMBER_OF_ALERTS"=>				"Aantal Alerten",
	"S_NUMBER_OF_TRIGGERS"=>			"Aantal Trekkers (geactiveerd/gedeactiveerd)[waar/onbekend/onwaar]",
	"S_NUMBER_OF_TRIGGERS_SHORT"=>		"Trekkers (e/d)[t/u/f]",
	"S_NUMBER_OF_ITEMS"=>				"Aantal Items (gemonitord/gedeactiveerd/niet ondersteund)[trapper]",
	"S_NUMBER_OF_ITEMS_SHORT"=>			"Items (m/d/n)[t]",
	"S_NUMBER_OF_USERS"=>				"Aantal Gebruikers (online)",
	"S_NUMBER_OF_USERS_SHORT"=>			"Gebruikers (online)",
	"S_NUMBER_OF_HOSTS"=>				"Aantal Gastheren (gemonitord/niet gemonitord/sjablonen/verwijderd)",
	"S_NUMBER_OF_HOSTS_SHORT"=>			"Gastheren (m/n/t/d)",
	"S_YES"=>							"Ja",
	"S_NO"=>							"Nee",
	"S_RUNNING"=>						"Lopende",
	"S_NOT_RUNNING"=>					"Niet lopende",

//	report2.php
	"S_AVAILABILITY_REPORT"=>			"Beschikbaarheids report",
	"S_AVAILABILITY_REPORT_BIG"=>		"BESCHIKBAARHEIDS REPORT",
	"S_SHOW"=>							"Toon",
	"S_TRUE"=>							"Waar",
	"S_FALSE"=>							"Onwaar",
	
//	report3.php
	"S_IT_SERVICES_AVAILABILITY_REPORT_BIG"=>	"IT DIENSTEN BESCHIKBAARHEIDS REPORT",
	"S_FROM"=>							"Van",
	"S_TILL"=>							"Tot",
	"S_OK"=>							"Ok",
	"S_PROBLEMS"=>						"Problemen",
	"S_PERCENTAGE"=>					"Percentage",
	"S_SLA"=>							"SLA",
	"S_DAY"=>							"Dag",
	"S_MONTH"=>							"Maand",
	"S_YEAR"=>							"Jaar",
	"S_DAILY"=>							"Dagelijks",
	"S_WEEKLY"=>						"Wekelijks",
	"S_MONTHLY"=>						"Maandelijks",
	"S_YEARLY"=>						"Jaarlijks",

//      report4.php
	"S_NOTIFICATIONS"=>					"Notificaties",
	"S_NOTIFICATIONS_BIG"=>				"NOTIFICATIES",
	"S_IT_NOTIFICATIONS"=>				"Notificaties report",

//	report5.php
    "S_TRIGGERS_TOP_100"=>				"Meest actieve trekkers top 100",
	"S_TRIGGERS_TOP_100_BIG"=>			"MEEST ACTIVE TREKKERS TOP 100",
	"S_NUMBER_OF_STATUS_CHANGES"=>		"Aantal keren veranderd",
	"S_WEEK"=>							"Week",
	"S_LAST"=>							"Laatst",
 
//	screenconf.php
	"S_SCREENS"=>						"Schermen",
	"S_SCREEN"=>						"Scherm",
	"S_CONFIGURATION_OF_SCREENS_BIG"=>	"CONFIGURATIE VAN SCHERMEN",
	"S_CONFIGURATION_OF_SCREENS"=>		"Configuratie van schermen",
	"S_SCREEN_ADDED"=>					"Scherm toegevoegd",
	"S_CANNOT_ADD_SCREEN"=>				"Kan scherm niet toevoegen",
	"S_SCREEN_UPDATED"=>				"Scherm bijgewerkt",
	"S_CANNOT_UPDATE_SCREEN"=>			"Kan scherm niet bijwerken",
	"S_SCREEN_DELETED"=>				"Scherm verwijderd",
	"S_CANNOT_DELETE_SCREEN"=>			"Kan scherm niet verwijderen",
	"S_COLUMNS"=>						"Kolomen",
	"S_ROWS"=>							"Rijen",
	"S_NO_SCREENS_DEFINED"=>			"Geen schermen gedefineerd",
	"S_DELETE_SCREEN_Q"=>				"Verwijder scherm?",
	"S_CONFIGURATION_OF_SCREEN_BIG"=>	"CONFIGURATIE VAN SCHERMEN",
	"S_SCREEN_CELL_CONFIGURATION"=>		"Scherm cel configuratie",
	"S_RESOURCE"=>						"Bron",
	"S_SIMPLE_GRAPH"=>					"Simpel grafiek",
	"S_GRAPH_NAME"=>					"Grafiek naam",
	"S_WIDTH"=>							"Breedte",
	"S_HEIGHT"=>						"Hoogte",
	"S_CREATE_SCREEN"=>					"Crer Scherm",
	"S_EDIT"=>							"Bijwerken",
	"S_DIMENSION_COLS_ROWS"=>			"Dimensies (kolomen x rijen)",

//	screenedit.php
	"S_MAP"=>							"Map",
	"S_AS_PLAIN_TEXT"=>					"Als platte teskst",
	"S_PLAIN_TEXT"=>					"Platte tekst",
	"S_COLUMN_SPAN"=>					"Kolom breedte",
	"S_ROW_SPAN"=>						"Rij breedte",
	"S_SHOW_LINES"=>					"Toon lijnen",
	"S_HOSTS_INFO"=>					"Gastheren info",
	"S_TRIGGERS_INFO"=>					"Trekkers info",
	"S_SERVER_INFO"=>					"Server info",
	"S_CLOCK"=>							"Klok",
	"S_TRIGGERS_OVERVIEW"=>				"Trekkers overzicht",
	"S_DATA_OVERVIEW"=>					"Data overzicht",
    "S_HISTORY_OF_ACTIONS"=>        	"Geschiedenis van acties",
    "S_HISTORY_OF_EVENTS"=>         	"Geschiedenis van gebeurtenissen",

	"S_TIME_TYPE"=>						"Tijd type",
	"S_SERVER_TIME"=>					"Server time",
	"S_LOCAL_TIME"=>					"Lokale tijd",

	"S_STYLE"=>							"Stijle",
	"S_VERTICAL"=>						"Verticaal",
	"S_HORISONTAL"=>					"Horizontaal",

	"S_HORISONTAL_ALIGN"=>				"Horizontale uitlijning",
	"S_LEFT"=>							"Links",
	"S_CENTER"=>						"Midden",
	"S_RIGHT"=>							"Rechts",

	"S_VERTICAL_ALIGN"=>				"Verticale uitlijning",
	"S_TOP"=>							"boven",
	"S_MIDDLE"=>						"midden",
	"S_BOTTOM"=>						"onder",

//	screens.php
	"S_CUSTOM_SCREENS"=>				"Specifieke Schermen",
	"S_SCREENS_BIG"=>					"SCHERMEN",
	"S_NO_SCREENS_TO_DISPLAY"=>			"Geen schermen om weer te geven",
	"S_SELECT_SCREEN_TO_DISPLAY"=>		"Selecteer een scherm voor weergave",
	"S_SELECT_SCREEN_DOT_DOT_DOT"=>		"Selecteer een scherm ...",

//	services.php
	"S_IT_SERVICES"=>					"IT Diensten",
	"S_SERVICE_UPDATED"=>				"Dienst bijgewerkt",
	"S_CANNOT_UPDATE_SERVICE"=>			"Kan dienst niet bijwerken",
	"S_SERVICE_ADDED"=>					"Dienst toegevoegd",
	"S_CANNOT_ADD_SERVICE"=>			"kan dienst niet toevoegen",
	"S_LINK_ADDED"=>					"Link toegevoegd",
	"S_CANNOT_ADD_LINK"=>				"kan link niet toevoegen",
	"S_SERVICE_DELETED"=>				"Dienst verwijderd",
	"S_CANNOT_DELETE_SERVICE"=>			"kan dienst niet verwijderen",
	"S_LINK_DELETED"=>					"Link verwijderd",
	"S_CANNOT_DELETE_LINK"=>			"Kan link niet verwijderen",
	"S_STATUS_CALCULATION"=>			"Status calculatie",
	"S_STATUS_CALCULATION_ALGORITHM"=>	"Status calculatie algoritme",
	"S_NONE"=>							"Geen",
	"S_MAX_OF_CHILDS"=>					"MAX kinderen",
	"S_MIN_OF_CHILDS"=>					"MIN kinderen",
	"S_SERVICE_1"=>						"Dienst 1",
	"S_SERVICE_2"=>						"Dienst 2",
	"S_SOFT_HARD_LINK"=>				"Soft/hard link",
	"S_SOFT"=>							"Soft",
	"S_HARD"=>							"Hard",
	"S_DO_NOT_CALCULATE"=>				"Bereken niet",
	"S_MAX_BIG"=>						"MAX",
	"S_MIN_BIG"=>						"MIN",
	"S_SHOW_SLA"=>						"Toon SLA",
	"S_ACCEPTABLE_SLA_IN_PERCENT"=>		"Accepteerbare SLA (in %)",
	"S_LINK_TO_TRIGGER_Q"=>				"Link naar Trekker?",
	"S_SORT_ORDER_0_999"=>				"Sorteer orde (0->999)",
	"S_DELETE_SERVICE_Q"=>				"S_VERWIJDER_DIENST_Q",
	"S_LINK_TO"=>						"Link naar",
	"S_SOFT_LINK_Q"=>					"Soft link?",
	"S_ADD_SERVER_DETAILS"=>			"Voeg server details toe",
	"S_TRIGGER"=>						"Trekker",
	"S_SERVER"=>						"Server",
	"S_DELETE"=>						"Verwijder",
	"S_DELETE_SELECTED_SERVICES"=>		"Verwijder geselecteerde diensten?",
	"S_DELETE_SELECTED_LINKS"=>			"Verwijder geselecteerde links?",
	"S_SERVICES_DELETED"=>				"Dienst Verwijderd",
	"S_CANNOT_DELETE_SERVICES"=>		"Kan dienst niet verwijderen",

//	srv_status.php
	"S_IT_SERVICES_BIG"=>				"IT DIENSTEN",
	"S_SERVICE"=>						"Diensten",
	"S_REASON"=>						"Reden",
	"S_SLA_LAST_7_DAYS"=>				"SLA (laatste 7 dagen)",
	"S_PLANNED_CURRENT_SLA"=>			"Gepland/Huidig SLA",
	"S_TRIGGER_BIG"=>					"TREKKER",

//	Trekkers.php
	"S_NO_TRIGGERS_DEFINED"=>			"Geen Trekkers gedefineerd",
	"S_CONFIGURATION_OF_TRIGGERS"=>		"Configuratie van Trekkers",
	"S_CONFIGURATION_OF_TRIGGERS_BIG"=>	"CONFIGURATIE VAN TREKKERS",
	"S_DEPENDENCY_ADDED"=>				"Afhankelijkheid toegevoegd",
	"S_CANNOT_ADD_DEPENDENCY"=>			"kan afhankelijkheid niet toevoegen",
	"S_TRIGGERS_UPDATED"=>				"Trekkers bijgewerkt",
	"S_CANNOT_UPDATE_TRIGGERS"=>		"Kan trekkers niet bijwerken",
	"S_TRIGGERS_DISABLED"=>				"Trekkers gedeactiveerd",
	"S_CANNOT_DISABLE_TRIGGERS"=>		"Kan trekkers niet deactiveren",
	"S_TRIGGERS_DELETED"=>				"Trekkers verwijderd",
	"S_CANNOT_DELETE_TRIGGERS"=>		"Kan trekkers niet verwijderen",
	"S_TRIGGER_DELETED"=>				"Trekker verwijderd",
	"S_CANNOT_DELETE_TRIGGER"=>			"Kan trekker niet verwijderen",
	"S_INVALID_TRIGGER_EXPRESSION"=>	"Ongeldige Trekker expressie",
	"S_TRIGGER_ADDED"=>					"Trekker toegevoegd",
	"S_CANNOT_ADD_TRIGGER"=>			"Kan trekker niet toevoegen",
	"S_SEVERITY"=>						"Ernstheid",
	"S_EXPRESSION"=>					"Expressie",
	"S_DISABLED"=>						"Gedeactiveerd",
	"S_ENABLED"=>						"Geactiveerd",
	"S_ENABLE_SELECTED_TRIGGERS_Q"=>	"Aktiveer geselecteerde trekkers?",
	"S_DISABLE_SELECTED_TRIGGERS_Q"=>	"Deactiveer geselecteerde trekkers?",
	"S_DELETE_SELECTED_TRIGGERS_Q"=>	"Verwijder geselecteerde trekkers?",
	"S_CHANGE"=>						"Aanpassen",
	"S_TRIGGER_UPDATED"=>				"Trekker bijgewerkt",
	"S_CANNOT_UPDATE_TRIGGER"=>			"Kan trekker niet bijwerken",
	"S_DEPENDS_ON"=>					"Afhankelijk van",
	"S_URL"=>							"URL",
	"S_CREATE_TRIGGER"=>				"Crer trekker",

//	tr_comments.php
	"S_TRIGGER_COMMENTS"=>				"Trekker opmerkingen",
	"S_TRIGGER_COMMENTS_BIG"=>			"TREKKER OPMERKINGEN",
	"S_COMMENT_UPDATED"=>				"Opmerkingen bijgewerkt",
	"S_CANNOT_UPDATE_COMMENT"=>			"Kan opmerkingen niet bijwerken",
	"S_ADD"=>							"Toevoegen",

//	tr_status.php
	"S_STATUS_OF_TRIGGERS"=>			"Status van trekkers",
	"S_STATUS_OF_TRIGGERS_BIG"=>		"STATUS VAN TREKKERS",
	"S_SHOW_ONLY_TRUE"=>				"Toon alleen waar",
	"S_HIDE_ACTIONS"=>					"Verberg acties",
	"S_SHOW_ACTIONS"=>					"Toon acties",
	"S_SHOW_ALL_TRIGGERS"=>				"Toon alle trekkers",
	"S_HIDE_DETAILS"=>					"Verberg details",
	"S_SHOW_DETAILS"=>					"Toon details",
	"S_SELECT"=>						"Selecteer",
	"S_HIDE_SELECT"=>					"Verberg selecteer",
	"S_TRIGGERS_BIG"=>					"Trekkers",
	"S_NAME_BIG"=>						"NAAM",
	"S_SEVERITY_BIG"=>					"Ernstheid",
	"S_LAST_CHANGE_BIG"=>				"LAATSTE VERANDERING",
	"S_LAST_CHANGE"=>					"Laatste verandering",
	"S_COMMENTS"=>						"Opmerkingen",
	"S_ACKNOWLEDGED"=>					"Herkenning",
	"S_ACK"=>							"Hng",

//	users.php
	"S_USERS"=>							"Gebruikers",
	"S_USER_ADDED"=>					"Gebruikers toegevoegd",
	"S_CANNOT_ADD_USER"=>				"Kan gebruiker niet toevoegen",
	"S_CANNOT_ADD_USER_BOTH_PASSWORDS_MUST"=>"Kan gebruiker niet toevoegen. Beide wachtwoorden moeten hetzelfde zijn.",
	"S_USER_DELETED"=>					"Gebruiker verwijderd",
	"S_CANNOT_DELETE_USER"=>			"Kan gebruikers niet verwijderen",
	"S_PERMISSION_DELETED"=>			"Rechten verwijderd",
	"S_CANNOT_DELETE_PERMISSION"=>		"Kan rechten niet verwijderen",
	"S_PERMISSION_ADDED"=>				"Rechten toegevoegd",
	"S_CANNOT_ADD_PERMISSION"=>			"Kan rechten niet toevoegen",
	"S_USER_UPDATED"=>					"Gebruiker bijgewerkt",
	"S_CANNOT_UPDATE_USER"=>			"Kan gebruiker niet bijwerken",
	"S_CANNOT_UPDATE_USER_BOTH_PASSWORDS"=>	"Kan gebruiker niet bijwerken. Beide wachtwoorden moeten hetzelfde zijn.",
	"S_GROUP_ADDED"=>					"Groep toegevoegd",
	"S_CANNOT_ADD_GROUP"=>				"Kan groep niet toevoegen",
	"S_GROUP_UPDATED"=>					"Groep bijgewerkt",
	"S_CANNOT_UPDATE_GROUP"=>			"Kan groep niet bijwerken",
	"S_GROUP_DELETED"=>					"Groep verwijderd",
	"S_CANNOT_DELETE_GROUP"=>			"Kan groep niet verwijderen",
	"S_CONFIGURATION_OF_USERS_AND_USER_GROUPS"=>"CONFIGURATIE VAN GEBRUIKERS AND GROEPEN",
	"S_USER_GROUPS_BIG"=>				"GEBRUIKERS GROEPEN",
	"S_USERS_BIG"=>						"GEBRUIKERS",
	"S_USER_GROUPS"=>					"Gebruikers groepen",
	"S_MEMBERS"=>						"Leden",
	"S_TEMPLATES"=>						"Sjablonen",
	"S_HOSTS_TEMPLATES_LINKAGE"=>		"Gastheren/Sjablonen verbindingen",
	"S_CONFIGURATION_OF_TEMPLATES_LINKAGE"=>"CONFIGURATIE VAN SJABLONEN VERBINDINGEN",
	"S_LINKED_TEMPLATES_BIG"=>			"VERBONDEN SJABLONEN",
	"S_NO_USER_GROUPS_DEFINED"=>		"Geen gebruiker groepen gedefineerd",
	"S_ALIAS"=>							"Alias",
	"S_NAME"=>							"Naam",
	"S_SURNAME"=>						"Achternaam",
	"S_IS_ONLINE_Q"=>					"Is verbonden?",
	"S_NO_USERS_DEFINED"=>				"Geen gebruikers gedefineerd",
	"S_PERMISSION"=>					"Rechten",
	"S_RIGHT"=>							"Recht",
	"S_RESOURCE_NAME"=>					"Bron naam",
	"S_READ_ONLY"=>						"Alleen lezen",
	"S_READ_WRITE"=>					"Lees-schrijf",
	"S_HIDE"=>							"Verberg",
	"S_PASSWORD"=>						"Wachtwoord",
	"S_PASSWORD_ONCE_AGAIN"=>			"Wachtwoord (normaals)",
	"S_URL_AFTER_LOGIN"=>				"URL (na de login)",
	"S_AUTO_LOGOUT_IN_SEC"=>			"Auto-loguit (in sec=>0 - gedeactiveerd)",
	"S_SCREEN_REFRESH"=>                "Verversing (in seconden)",
	"S_CREATE_USER"=>					"Crer Gebruiker",
	"S_CREATE_GROUP"=>					"Crer Groep",

//	audit.php
	"S_AUDIT_LOG"=>						"Controle log",
	"S_AUDIT_LOG_BIG"=>					"CONTROLE LOG",
	"S_ACTION"=>						"Actie",
	"S_DETAILS"=>						"Details",
	"S_UNKNOWN_ACTION"=>				"Onbekende actie",
	"S_ADDED"=>							"Toegevoegd",
	"S_UPDATED"=>						"Bijgewerkt",
	"S_LOGGED_IN"=>						"Ingelogd",
	"S_LOGGED_OUT"=>					"Uitgelogd",
	"S_MEDIA_TYPE"=>					"Media type",
	"S_GRAPH_ELEMENT"=>					"Grafiek element",
	"S_UNKNOWN_RESOURCE"=>				"Onbekende bron",

//	profile.php
	"S_USER_PROFILE_BIG"=>				"GEBRUIKERS PROFIEL",
	"S_USER_PROFILE"=>					"Gebruikers profiel",
	"S_LANGUAGE"=>						"Taal",
	"S_ENGLISH_GB"=>					"English (GB)",
	"S_DUTCH_NL"=>						"Dutch (NL)",
	"S_FRENCH_FR"=>						"French (FR)",
	"S_GERMAN_DE"=>						"German (DE)",
	"S_ITALIAN_IT"=>					"Italian (IT)",
	"S_LATVIAN_LV"=>					"Latvian (LV)",
	"S_RUSSIAN_RU"=>					"Russian (RU)",
	"S_SPANISH_SP"=>					"Spanish (SP)",
	"S_JAPANESE_JP"=>					"Japanese (JP)",
	"S_CHINESE_CN"=>					"Chinese (CN)",

//	index.php
	"S_ZABBIX_BIG"=>					"ZABBIX",

//	gastheerprofiles.php
	"S_HOST_PROFILES"=>					"Gastheren profielen",
	"S_HOST_PROFILES_BIG"=>				"GASTHEER PROFIELEN",

//	bulkloader.php
	"S_MENU_BULKLOADER"=>				"Bulklader",
	"S_BULKLOADER_MAIN"=>				"Bulklader: Hoofd Pagina",
	"S_BULKLOADER_HOSTS"=>				"Bulklader: Gastheren",
	"S_BULKLOADER_ITEMS"=>				"Bulklader: Items",
	"S_BULKLOADER_USERS"=>				"Bulklader: Gebruikers",
	"S_BULKLOADER_TRIGGERS"=>			"Bulklader: Trekkers",
	"S_BULKLOADER_ACTIONS"=>			"Bulklader: Acties",
	"S_BULKLOADER_ITSERVICES"=>			"Bulklader: IT Diensten",

	"S_BULKLOADER_IMPORT_HOSTS"=>		"Import Gastheren",
	"S_BULKLOADER_IMPORT_ITEMS"=>		"Import Items",
	"S_BULKLOADER_IMPORT_USERS"=>		"Import Gebruikers",
	"S_BULKLOADER_IMPORT_TRIGGERS"=>	"Import Trekkers",
	"S_BULKLOADER_IMPORT_ACTIONS"=>		"Import Acties",
	"S_BULKLOADER_IMPORT_ITSERVICES"=>	"Import IT Diensten",

//	popup.php
	"S_EMPTY"=>							"Leeg",
	"S_STANDARD_ITEMS_BIG"=>			"STANDAARD ITEMS",
	"S_NO_ITEMS"=>						"Geen items",

//	Menu

	"S_HELP"=>							"Help",
	"S_PROFILE"=>						"Profiel",
	"S_MONITORING"=>					"Monitoring",
	"S_INVENTORY"=>						"Inventaris",
	"S_QUEUE"=>							"Wachtrij",
	"S_EVENTS"=>						"Gebeurtenissen",
	"S_MAPS"=>							"Mappen",
	"S_REPORTS"=>						"Reporten",
	"S_GENERAL"=>						"Algemeen",
	"S_AUDIT"=>							"Controle",
	"S_LOGIN"=>							"Login",
	"S_LATEST_DATA"=>					"Laatste data",

//	Errors
	"S_INCORRECT_DESCRIPTION"=>			"Incorrecte omschrijving"
	);
?>
